# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tensorboard/uploader/proto/write_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from tensorboard.uploader.proto import experiment_pb2 as tensorboard_dot_uploader_dot_proto_dot_experiment__pb2
from tensorboard.uploader.proto import scalar_pb2 as tensorboard_dot_uploader_dot_proto_dot_scalar__pb2
from tensorboard.uploader.proto import tensor_pb2 as tensorboard_dot_uploader_dot_proto_dot_tensor__pb2
from tensorboard.uploader.proto import blob_pb2 as tensorboard_dot_uploader_dot_proto_dot_blob__pb2
from tensorboard.compat.proto import summary_pb2 as tensorboard_dot_compat_dot_proto_dot_summary__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tensorboard/uploader/proto/write_service.proto',
  package='tensorboard.service',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n.tensorboard/uploader/proto/write_service.proto\x12\x13tensorboard.service\x1a\x1fgoogle/protobuf/timestamp.proto\x1a+tensorboard/uploader/proto/experiment.proto\x1a\'tensorboard/uploader/proto/scalar.proto\x1a\'tensorboard/uploader/proto/tensor.proto\x1a%tensorboard/uploader/proto/blob.proto\x1a&tensorboard/compat/proto/summary.proto\"<\n\x17\x43reateExperimentRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\">\n\x18\x43reateExperimentResponse\x12\x15\n\rexperiment_id\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\"\x8c\x01\n\x17UpdateExperimentRequest\x12\x33\n\nexperiment\x18\x01 \x01(\x0b\x32\x1f.tensorboard.service.Experiment\x12<\n\x0f\x65xperiment_mask\x18\x02 \x01(\x0b\x32#.tensorboard.service.ExperimentMask\"\x1a\n\x18UpdateExperimentResponse\"0\n\x17\x44\x65leteExperimentRequest\x12\x15\n\rexperiment_id\x18\x01 \x01(\t\"\x1a\n\x18\x44\x65leteExperimentResponse\"\'\n\x10PurgeDataRequest\x12\x13\n\x0b\x62\x61tch_limit\x18\x01 \x01(\x05\"I\n\x11PurgeDataResponse\x12\x34\n\x0bpurge_stats\x18\x01 \x01(\x0b\x32\x1f.tensorboard.service.PurgeStats\">\n\nPurgeStats\x12\x0c\n\x04tags\x18\x01 \x01(\x05\x12\x13\n\x0b\x65xperiments\x18\x02 \x01(\x05\x12\r\n\x05users\x18\x03 \x01(\x05\"\xad\x02\n\x12WriteScalarRequest\x12\x15\n\rexperiment_id\x18\x01 \x01(\t\x12\x39\n\x04runs\x18\x02 \x03(\x0b\x32+.tensorboard.service.WriteScalarRequest.Run\x1aN\n\x03Run\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x39\n\x04tags\x18\x02 \x03(\x0b\x32+.tensorboard.service.WriteScalarRequest.Tag\x1au\n\x03Tag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x30\n\x06points\x18\x02 \x03(\x0b\x32 .tensorboard.service.ScalarPoint\x12.\n\x08metadata\x18\x03 \x01(\x0b\x32\x1c.tensorboard.SummaryMetadata\"\x15\n\x13WriteScalarResponse\"\xad\x02\n\x12WriteTensorRequest\x12\x15\n\rexperiment_id\x18\x01 \x01(\t\x12\x39\n\x04runs\x18\x02 \x03(\x0b\x32+.tensorboard.service.WriteTensorRequest.Run\x1aN\n\x03Run\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x39\n\x04tags\x18\x02 \x03(\x0b\x32+.tensorboard.service.WriteTensorRequest.Tag\x1au\n\x03Tag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x30\n\x06points\x18\x02 \x03(\x0b\x32 .tensorboard.service.TensorPoint\x12.\n\x08metadata\x18\x03 \x01(\x0b\x32\x1c.tensorboard.SummaryMetadata\"\x15\n\x13WriteTensorResponse\"\xdd\x01\n\x1eGetOrCreateBlobSequenceRequest\x12\x15\n\rexperiment_id\x18\x01 \x01(\t\x12\x0b\n\x03run\x18\x02 \x01(\t\x12\x0b\n\x03tag\x18\x03 \x01(\t\x12\x0c\n\x04step\x18\x04 \x01(\x03\x12-\n\twall_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1d\n\x15\x66inal_sequence_length\x18\x06 \x01(\x03\x12.\n\x08metadata\x18\x07 \x01(\x0b\x32\x1c.tensorboard.SummaryMetadata\";\n\x1fGetOrCreateBlobSequenceResponse\x12\x18\n\x10\x62lob_sequence_id\x18\x01 \x01(\t\"A\n\x16GetBlobMetadataRequest\x12\x18\n\x10\x62lob_sequence_id\x18\x01 \x01(\t\x12\r\n\x05index\x18\x02 \x01(\x03\"k\n\x17GetBlobMetadataResponse\x12\x32\n\nblob_state\x18\x01 \x01(\x0e\x32\x1e.tensorboard.service.BlobState\x12\x0c\n\x04size\x18\x02 \x01(\x03\x12\x0e\n\x06\x63rc32c\x18\x03 \x01(\x07\"\xac\x01\n\x10WriteBlobRequest\x12\x18\n\x10\x62lob_sequence_id\x18\x01 \x01(\t\x12\r\n\x05index\x18\x02 \x01(\x03\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\x12\x0e\n\x06offset\x18\x04 \x01(\x03\x12\x0e\n\x06\x63rc32c\x18\x05 \x01(\x07\x12\x17\n\x0f\x66inalize_object\x18\x06 \x01(\x08\x12\x14\n\x0c\x66inal_crc32c\x18\x07 \x01(\x07\x12\x12\n\nblob_bytes\x18\x08 \x01(\x03\"U\n\x11WriteBlobResponse\x12\x32\n\nblob_state\x18\x01 \x01(\x0e\x32\x1e.tensorboard.service.BlobState\x12\x0c\n\x04size\x18\x02 \x01(\x03\"\x16\n\x14\x44\x65leteOwnUserRequest\"\x17\n\x15\x44\x65leteOwnUserResponse2\xde\x08\n\x18TensorBoardWriterService\x12q\n\x10\x43reateExperiment\x12,.tensorboard.service.CreateExperimentRequest\x1a-.tensorboard.service.CreateExperimentResponse\"\x00\x12q\n\x10UpdateExperiment\x12,.tensorboard.service.UpdateExperimentRequest\x1a-.tensorboard.service.UpdateExperimentResponse\"\x00\x12q\n\x10\x44\x65leteExperiment\x12,.tensorboard.service.DeleteExperimentRequest\x1a-.tensorboard.service.DeleteExperimentResponse\"\x00\x12\\\n\tPurgeData\x12%.tensorboard.service.PurgeDataRequest\x1a&.tensorboard.service.PurgeDataResponse\"\x00\x12\x62\n\x0bWriteScalar\x12\'.tensorboard.service.WriteScalarRequest\x1a(.tensorboard.service.WriteScalarResponse\"\x00\x12\x62\n\x0bWriteTensor\x12\'.tensorboard.service.WriteTensorRequest\x1a(.tensorboard.service.WriteTensorResponse\"\x00\x12\x86\x01\n\x17GetOrCreateBlobSequence\x12\x33.tensorboard.service.GetOrCreateBlobSequenceRequest\x1a\x34.tensorboard.service.GetOrCreateBlobSequenceResponse\"\x00\x12n\n\x0fGetBlobMetadata\x12+.tensorboard.service.GetBlobMetadataRequest\x1a,.tensorboard.service.GetBlobMetadataResponse\"\x00\x12`\n\tWriteBlob\x12%.tensorboard.service.WriteBlobRequest\x1a&.tensorboard.service.WriteBlobResponse\"\x00(\x01\x30\x01\x12h\n\rDeleteOwnUser\x12).tensorboard.service.DeleteOwnUserRequest\x1a*.tensorboard.service.DeleteOwnUserResponse\"\x00\x62\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,tensorboard_dot_uploader_dot_proto_dot_experiment__pb2.DESCRIPTOR,tensorboard_dot_uploader_dot_proto_dot_scalar__pb2.DESCRIPTOR,tensorboard_dot_uploader_dot_proto_dot_tensor__pb2.DESCRIPTOR,tensorboard_dot_uploader_dot_proto_dot_blob__pb2.DESCRIPTOR,tensorboard_dot_compat_dot_proto_dot_summary__pb2.DESCRIPTOR,])




_CREATEEXPERIMENTREQUEST = _descriptor.Descriptor(
  name='CreateExperimentRequest',
  full_name='tensorboard.service.CreateExperimentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='tensorboard.service.CreateExperimentRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='tensorboard.service.CreateExperimentRequest.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=310,
  serialized_end=370,
)


_CREATEEXPERIMENTRESPONSE = _descriptor.Descriptor(
  name='CreateExperimentResponse',
  full_name='tensorboard.service.CreateExperimentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='experiment_id', full_name='tensorboard.service.CreateExperimentResponse.experiment_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='url', full_name='tensorboard.service.CreateExperimentResponse.url', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=372,
  serialized_end=434,
)


_UPDATEEXPERIMENTREQUEST = _descriptor.Descriptor(
  name='UpdateExperimentRequest',
  full_name='tensorboard.service.UpdateExperimentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='experiment', full_name='tensorboard.service.UpdateExperimentRequest.experiment', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='experiment_mask', full_name='tensorboard.service.UpdateExperimentRequest.experiment_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=437,
  serialized_end=577,
)


_UPDATEEXPERIMENTRESPONSE = _descriptor.Descriptor(
  name='UpdateExperimentResponse',
  full_name='tensorboard.service.UpdateExperimentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=579,
  serialized_end=605,
)


_DELETEEXPERIMENTREQUEST = _descriptor.Descriptor(
  name='DeleteExperimentRequest',
  full_name='tensorboard.service.DeleteExperimentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='experiment_id', full_name='tensorboard.service.DeleteExperimentRequest.experiment_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=607,
  serialized_end=655,
)


_DELETEEXPERIMENTRESPONSE = _descriptor.Descriptor(
  name='DeleteExperimentResponse',
  full_name='tensorboard.service.DeleteExperimentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=657,
  serialized_end=683,
)


_PURGEDATAREQUEST = _descriptor.Descriptor(
  name='PurgeDataRequest',
  full_name='tensorboard.service.PurgeDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='batch_limit', full_name='tensorboard.service.PurgeDataRequest.batch_limit', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=685,
  serialized_end=724,
)


_PURGEDATARESPONSE = _descriptor.Descriptor(
  name='PurgeDataResponse',
  full_name='tensorboard.service.PurgeDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='purge_stats', full_name='tensorboard.service.PurgeDataResponse.purge_stats', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=726,
  serialized_end=799,
)


_PURGESTATS = _descriptor.Descriptor(
  name='PurgeStats',
  full_name='tensorboard.service.PurgeStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tags', full_name='tensorboard.service.PurgeStats.tags', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='experiments', full_name='tensorboard.service.PurgeStats.experiments', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='users', full_name='tensorboard.service.PurgeStats.users', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=801,
  serialized_end=863,
)


_WRITESCALARREQUEST_RUN = _descriptor.Descriptor(
  name='Run',
  full_name='tensorboard.service.WriteScalarRequest.Run',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='tensorboard.service.WriteScalarRequest.Run.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tags', full_name='tensorboard.service.WriteScalarRequest.Run.tags', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=970,
  serialized_end=1048,
)

_WRITESCALARREQUEST_TAG = _descriptor.Descriptor(
  name='Tag',
  full_name='tensorboard.service.WriteScalarRequest.Tag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='tensorboard.service.WriteScalarRequest.Tag.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='points', full_name='tensorboard.service.WriteScalarRequest.Tag.points', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='tensorboard.service.WriteScalarRequest.Tag.metadata', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1050,
  serialized_end=1167,
)

_WRITESCALARREQUEST = _descriptor.Descriptor(
  name='WriteScalarRequest',
  full_name='tensorboard.service.WriteScalarRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='experiment_id', full_name='tensorboard.service.WriteScalarRequest.experiment_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='runs', full_name='tensorboard.service.WriteScalarRequest.runs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_WRITESCALARREQUEST_RUN, _WRITESCALARREQUEST_TAG, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=866,
  serialized_end=1167,
)


_WRITESCALARRESPONSE = _descriptor.Descriptor(
  name='WriteScalarResponse',
  full_name='tensorboard.service.WriteScalarResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1169,
  serialized_end=1190,
)


_WRITETENSORREQUEST_RUN = _descriptor.Descriptor(
  name='Run',
  full_name='tensorboard.service.WriteTensorRequest.Run',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='tensorboard.service.WriteTensorRequest.Run.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tags', full_name='tensorboard.service.WriteTensorRequest.Run.tags', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1297,
  serialized_end=1375,
)

_WRITETENSORREQUEST_TAG = _descriptor.Descriptor(
  name='Tag',
  full_name='tensorboard.service.WriteTensorRequest.Tag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='tensorboard.service.WriteTensorRequest.Tag.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='points', full_name='tensorboard.service.WriteTensorRequest.Tag.points', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='tensorboard.service.WriteTensorRequest.Tag.metadata', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1377,
  serialized_end=1494,
)

_WRITETENSORREQUEST = _descriptor.Descriptor(
  name='WriteTensorRequest',
  full_name='tensorboard.service.WriteTensorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='experiment_id', full_name='tensorboard.service.WriteTensorRequest.experiment_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='runs', full_name='tensorboard.service.WriteTensorRequest.runs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_WRITETENSORREQUEST_RUN, _WRITETENSORREQUEST_TAG, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1193,
  serialized_end=1494,
)


_WRITETENSORRESPONSE = _descriptor.Descriptor(
  name='WriteTensorResponse',
  full_name='tensorboard.service.WriteTensorResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1496,
  serialized_end=1517,
)


_GETORCREATEBLOBSEQUENCEREQUEST = _descriptor.Descriptor(
  name='GetOrCreateBlobSequenceRequest',
  full_name='tensorboard.service.GetOrCreateBlobSequenceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='experiment_id', full_name='tensorboard.service.GetOrCreateBlobSequenceRequest.experiment_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='run', full_name='tensorboard.service.GetOrCreateBlobSequenceRequest.run', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tag', full_name='tensorboard.service.GetOrCreateBlobSequenceRequest.tag', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='step', full_name='tensorboard.service.GetOrCreateBlobSequenceRequest.step', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wall_time', full_name='tensorboard.service.GetOrCreateBlobSequenceRequest.wall_time', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='final_sequence_length', full_name='tensorboard.service.GetOrCreateBlobSequenceRequest.final_sequence_length', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='tensorboard.service.GetOrCreateBlobSequenceRequest.metadata', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1520,
  serialized_end=1741,
)


_GETORCREATEBLOBSEQUENCERESPONSE = _descriptor.Descriptor(
  name='GetOrCreateBlobSequenceResponse',
  full_name='tensorboard.service.GetOrCreateBlobSequenceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blob_sequence_id', full_name='tensorboard.service.GetOrCreateBlobSequenceResponse.blob_sequence_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1743,
  serialized_end=1802,
)


_GETBLOBMETADATAREQUEST = _descriptor.Descriptor(
  name='GetBlobMetadataRequest',
  full_name='tensorboard.service.GetBlobMetadataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blob_sequence_id', full_name='tensorboard.service.GetBlobMetadataRequest.blob_sequence_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='index', full_name='tensorboard.service.GetBlobMetadataRequest.index', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1804,
  serialized_end=1869,
)


_GETBLOBMETADATARESPONSE = _descriptor.Descriptor(
  name='GetBlobMetadataResponse',
  full_name='tensorboard.service.GetBlobMetadataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blob_state', full_name='tensorboard.service.GetBlobMetadataResponse.blob_state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='tensorboard.service.GetBlobMetadataResponse.size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='crc32c', full_name='tensorboard.service.GetBlobMetadataResponse.crc32c', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1871,
  serialized_end=1978,
)


_WRITEBLOBREQUEST = _descriptor.Descriptor(
  name='WriteBlobRequest',
  full_name='tensorboard.service.WriteBlobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blob_sequence_id', full_name='tensorboard.service.WriteBlobRequest.blob_sequence_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='index', full_name='tensorboard.service.WriteBlobRequest.index', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='tensorboard.service.WriteBlobRequest.data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offset', full_name='tensorboard.service.WriteBlobRequest.offset', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='crc32c', full_name='tensorboard.service.WriteBlobRequest.crc32c', index=4,
      number=5, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='finalize_object', full_name='tensorboard.service.WriteBlobRequest.finalize_object', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='final_crc32c', full_name='tensorboard.service.WriteBlobRequest.final_crc32c', index=6,
      number=7, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blob_bytes', full_name='tensorboard.service.WriteBlobRequest.blob_bytes', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1981,
  serialized_end=2153,
)


_WRITEBLOBRESPONSE = _descriptor.Descriptor(
  name='WriteBlobResponse',
  full_name='tensorboard.service.WriteBlobResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blob_state', full_name='tensorboard.service.WriteBlobResponse.blob_state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='tensorboard.service.WriteBlobResponse.size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2155,
  serialized_end=2240,
)


_DELETEOWNUSERREQUEST = _descriptor.Descriptor(
  name='DeleteOwnUserRequest',
  full_name='tensorboard.service.DeleteOwnUserRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2242,
  serialized_end=2264,
)


_DELETEOWNUSERRESPONSE = _descriptor.Descriptor(
  name='DeleteOwnUserResponse',
  full_name='tensorboard.service.DeleteOwnUserResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2266,
  serialized_end=2289,
)

_UPDATEEXPERIMENTREQUEST.fields_by_name['experiment'].message_type = tensorboard_dot_uploader_dot_proto_dot_experiment__pb2._EXPERIMENT
_UPDATEEXPERIMENTREQUEST.fields_by_name['experiment_mask'].message_type = tensorboard_dot_uploader_dot_proto_dot_experiment__pb2._EXPERIMENTMASK
_PURGEDATARESPONSE.fields_by_name['purge_stats'].message_type = _PURGESTATS
_WRITESCALARREQUEST_RUN.fields_by_name['tags'].message_type = _WRITESCALARREQUEST_TAG
_WRITESCALARREQUEST_RUN.containing_type = _WRITESCALARREQUEST
_WRITESCALARREQUEST_TAG.fields_by_name['points'].message_type = tensorboard_dot_uploader_dot_proto_dot_scalar__pb2._SCALARPOINT
_WRITESCALARREQUEST_TAG.fields_by_name['metadata'].message_type = tensorboard_dot_compat_dot_proto_dot_summary__pb2._SUMMARYMETADATA
_WRITESCALARREQUEST_TAG.containing_type = _WRITESCALARREQUEST
_WRITESCALARREQUEST.fields_by_name['runs'].message_type = _WRITESCALARREQUEST_RUN
_WRITETENSORREQUEST_RUN.fields_by_name['tags'].message_type = _WRITETENSORREQUEST_TAG
_WRITETENSORREQUEST_RUN.containing_type = _WRITETENSORREQUEST
_WRITETENSORREQUEST_TAG.fields_by_name['points'].message_type = tensorboard_dot_uploader_dot_proto_dot_tensor__pb2._TENSORPOINT
_WRITETENSORREQUEST_TAG.fields_by_name['metadata'].message_type = tensorboard_dot_compat_dot_proto_dot_summary__pb2._SUMMARYMETADATA
_WRITETENSORREQUEST_TAG.containing_type = _WRITETENSORREQUEST
_WRITETENSORREQUEST.fields_by_name['runs'].message_type = _WRITETENSORREQUEST_RUN
_GETORCREATEBLOBSEQUENCEREQUEST.fields_by_name['wall_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_GETORCREATEBLOBSEQUENCEREQUEST.fields_by_name['metadata'].message_type = tensorboard_dot_compat_dot_proto_dot_summary__pb2._SUMMARYMETADATA
_GETBLOBMETADATARESPONSE.fields_by_name['blob_state'].enum_type = tensorboard_dot_uploader_dot_proto_dot_blob__pb2._BLOBSTATE
_WRITEBLOBRESPONSE.fields_by_name['blob_state'].enum_type = tensorboard_dot_uploader_dot_proto_dot_blob__pb2._BLOBSTATE
DESCRIPTOR.message_types_by_name['CreateExperimentRequest'] = _CREATEEXPERIMENTREQUEST
DESCRIPTOR.message_types_by_name['CreateExperimentResponse'] = _CREATEEXPERIMENTRESPONSE
DESCRIPTOR.message_types_by_name['UpdateExperimentRequest'] = _UPDATEEXPERIMENTREQUEST
DESCRIPTOR.message_types_by_name['UpdateExperimentResponse'] = _UPDATEEXPERIMENTRESPONSE
DESCRIPTOR.message_types_by_name['DeleteExperimentRequest'] = _DELETEEXPERIMENTREQUEST
DESCRIPTOR.message_types_by_name['DeleteExperimentResponse'] = _DELETEEXPERIMENTRESPONSE
DESCRIPTOR.message_types_by_name['PurgeDataRequest'] = _PURGEDATAREQUEST
DESCRIPTOR.message_types_by_name['PurgeDataResponse'] = _PURGEDATARESPONSE
DESCRIPTOR.message_types_by_name['PurgeStats'] = _PURGESTATS
DESCRIPTOR.message_types_by_name['WriteScalarRequest'] = _WRITESCALARREQUEST
DESCRIPTOR.message_types_by_name['WriteScalarResponse'] = _WRITESCALARRESPONSE
DESCRIPTOR.message_types_by_name['WriteTensorRequest'] = _WRITETENSORREQUEST
DESCRIPTOR.message_types_by_name['WriteTensorResponse'] = _WRITETENSORRESPONSE
DESCRIPTOR.message_types_by_name['GetOrCreateBlobSequenceRequest'] = _GETORCREATEBLOBSEQUENCEREQUEST
DESCRIPTOR.message_types_by_name['GetOrCreateBlobSequenceResponse'] = _GETORCREATEBLOBSEQUENCERESPONSE
DESCRIPTOR.message_types_by_name['GetBlobMetadataRequest'] = _GETBLOBMETADATAREQUEST
DESCRIPTOR.message_types_by_name['GetBlobMetadataResponse'] = _GETBLOBMETADATARESPONSE
DESCRIPTOR.message_types_by_name['WriteBlobRequest'] = _WRITEBLOBREQUEST
DESCRIPTOR.message_types_by_name['WriteBlobResponse'] = _WRITEBLOBRESPONSE
DESCRIPTOR.message_types_by_name['DeleteOwnUserRequest'] = _DELETEOWNUSERREQUEST
DESCRIPTOR.message_types_by_name['DeleteOwnUserResponse'] = _DELETEOWNUSERRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateExperimentRequest = _reflection.GeneratedProtocolMessageType('CreateExperimentRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEEXPERIMENTREQUEST,
  '__module__' : 'tensorboard.uploader.proto.write_service_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.service.CreateExperimentRequest)
  })
_sym_db.RegisterMessage(CreateExperimentRequest)

CreateExperimentResponse = _reflection.GeneratedProtocolMessageType('CreateExperimentResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEEXPERIMENTRESPONSE,
  '__module__' : 'tensorboard.uploader.proto.write_service_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.service.CreateExperimentResponse)
  })
_sym_db.RegisterMessage(CreateExperimentResponse)

UpdateExperimentRequest = _reflection.GeneratedProtocolMessageType('UpdateExperimentRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEEXPERIMENTREQUEST,
  '__module__' : 'tensorboard.uploader.proto.write_service_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.service.UpdateExperimentRequest)
  })
_sym_db.RegisterMessage(UpdateExperimentRequest)

UpdateExperimentResponse = _reflection.GeneratedProtocolMessageType('UpdateExperimentResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEEXPERIMENTRESPONSE,
  '__module__' : 'tensorboard.uploader.proto.write_service_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.service.UpdateExperimentResponse)
  })
_sym_db.RegisterMessage(UpdateExperimentResponse)

DeleteExperimentRequest = _reflection.GeneratedProtocolMessageType('DeleteExperimentRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEEXPERIMENTREQUEST,
  '__module__' : 'tensorboard.uploader.proto.write_service_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.service.DeleteExperimentRequest)
  })
_sym_db.RegisterMessage(DeleteExperimentRequest)

DeleteExperimentResponse = _reflection.GeneratedProtocolMessageType('DeleteExperimentResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEEXPERIMENTRESPONSE,
  '__module__' : 'tensorboard.uploader.proto.write_service_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.service.DeleteExperimentResponse)
  })
_sym_db.RegisterMessage(DeleteExperimentResponse)

PurgeDataRequest = _reflection.GeneratedProtocolMessageType('PurgeDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _PURGEDATAREQUEST,
  '__module__' : 'tensorboard.uploader.proto.write_service_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.service.PurgeDataRequest)
  })
_sym_db.RegisterMessage(PurgeDataRequest)

PurgeDataResponse = _reflection.GeneratedProtocolMessageType('PurgeDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _PURGEDATARESPONSE,
  '__module__' : 'tensorboard.uploader.proto.write_service_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.service.PurgeDataResponse)
  })
_sym_db.RegisterMessage(PurgeDataResponse)

PurgeStats = _reflection.GeneratedProtocolMessageType('PurgeStats', (_message.Message,), {
  'DESCRIPTOR' : _PURGESTATS,
  '__module__' : 'tensorboard.uploader.proto.write_service_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.service.PurgeStats)
  })
_sym_db.RegisterMessage(PurgeStats)

WriteScalarRequest = _reflection.GeneratedProtocolMessageType('WriteScalarRequest', (_message.Message,), {

  'Run' : _reflection.GeneratedProtocolMessageType('Run', (_message.Message,), {
    'DESCRIPTOR' : _WRITESCALARREQUEST_RUN,
    '__module__' : 'tensorboard.uploader.proto.write_service_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.service.WriteScalarRequest.Run)
    })
  ,

  'Tag' : _reflection.GeneratedProtocolMessageType('Tag', (_message.Message,), {
    'DESCRIPTOR' : _WRITESCALARREQUEST_TAG,
    '__module__' : 'tensorboard.uploader.proto.write_service_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.service.WriteScalarRequest.Tag)
    })
  ,
  'DESCRIPTOR' : _WRITESCALARREQUEST,
  '__module__' : 'tensorboard.uploader.proto.write_service_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.service.WriteScalarRequest)
  })
_sym_db.RegisterMessage(WriteScalarRequest)
_sym_db.RegisterMessage(WriteScalarRequest.Run)
_sym_db.RegisterMessage(WriteScalarRequest.Tag)

WriteScalarResponse = _reflection.GeneratedProtocolMessageType('WriteScalarResponse', (_message.Message,), {
  'DESCRIPTOR' : _WRITESCALARRESPONSE,
  '__module__' : 'tensorboard.uploader.proto.write_service_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.service.WriteScalarResponse)
  })
_sym_db.RegisterMessage(WriteScalarResponse)

WriteTensorRequest = _reflection.GeneratedProtocolMessageType('WriteTensorRequest', (_message.Message,), {

  'Run' : _reflection.GeneratedProtocolMessageType('Run', (_message.Message,), {
    'DESCRIPTOR' : _WRITETENSORREQUEST_RUN,
    '__module__' : 'tensorboard.uploader.proto.write_service_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.service.WriteTensorRequest.Run)
    })
  ,

  'Tag' : _reflection.GeneratedProtocolMessageType('Tag', (_message.Message,), {
    'DESCRIPTOR' : _WRITETENSORREQUEST_TAG,
    '__module__' : 'tensorboard.uploader.proto.write_service_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.service.WriteTensorRequest.Tag)
    })
  ,
  'DESCRIPTOR' : _WRITETENSORREQUEST,
  '__module__' : 'tensorboard.uploader.proto.write_service_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.service.WriteTensorRequest)
  })
_sym_db.RegisterMessage(WriteTensorRequest)
_sym_db.RegisterMessage(WriteTensorRequest.Run)
_sym_db.RegisterMessage(WriteTensorRequest.Tag)

WriteTensorResponse = _reflection.GeneratedProtocolMessageType('WriteTensorResponse', (_message.Message,), {
  'DESCRIPTOR' : _WRITETENSORRESPONSE,
  '__module__' : 'tensorboard.uploader.proto.write_service_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.service.WriteTensorResponse)
  })
_sym_db.RegisterMessage(WriteTensorResponse)

GetOrCreateBlobSequenceRequest = _reflection.GeneratedProtocolMessageType('GetOrCreateBlobSequenceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETORCREATEBLOBSEQUENCEREQUEST,
  '__module__' : 'tensorboard.uploader.proto.write_service_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.service.GetOrCreateBlobSequenceRequest)
  })
_sym_db.RegisterMessage(GetOrCreateBlobSequenceRequest)

GetOrCreateBlobSequenceResponse = _reflection.GeneratedProtocolMessageType('GetOrCreateBlobSequenceResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETORCREATEBLOBSEQUENCERESPONSE,
  '__module__' : 'tensorboard.uploader.proto.write_service_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.service.GetOrCreateBlobSequenceResponse)
  })
_sym_db.RegisterMessage(GetOrCreateBlobSequenceResponse)

GetBlobMetadataRequest = _reflection.GeneratedProtocolMessageType('GetBlobMetadataRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOBMETADATAREQUEST,
  '__module__' : 'tensorboard.uploader.proto.write_service_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.service.GetBlobMetadataRequest)
  })
_sym_db.RegisterMessage(GetBlobMetadataRequest)

GetBlobMetadataResponse = _reflection.GeneratedProtocolMessageType('GetBlobMetadataResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOBMETADATARESPONSE,
  '__module__' : 'tensorboard.uploader.proto.write_service_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.service.GetBlobMetadataResponse)
  })
_sym_db.RegisterMessage(GetBlobMetadataResponse)

WriteBlobRequest = _reflection.GeneratedProtocolMessageType('WriteBlobRequest', (_message.Message,), {
  'DESCRIPTOR' : _WRITEBLOBREQUEST,
  '__module__' : 'tensorboard.uploader.proto.write_service_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.service.WriteBlobRequest)
  })
_sym_db.RegisterMessage(WriteBlobRequest)

WriteBlobResponse = _reflection.GeneratedProtocolMessageType('WriteBlobResponse', (_message.Message,), {
  'DESCRIPTOR' : _WRITEBLOBRESPONSE,
  '__module__' : 'tensorboard.uploader.proto.write_service_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.service.WriteBlobResponse)
  })
_sym_db.RegisterMessage(WriteBlobResponse)

DeleteOwnUserRequest = _reflection.GeneratedProtocolMessageType('DeleteOwnUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEOWNUSERREQUEST,
  '__module__' : 'tensorboard.uploader.proto.write_service_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.service.DeleteOwnUserRequest)
  })
_sym_db.RegisterMessage(DeleteOwnUserRequest)

DeleteOwnUserResponse = _reflection.GeneratedProtocolMessageType('DeleteOwnUserResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEOWNUSERRESPONSE,
  '__module__' : 'tensorboard.uploader.proto.write_service_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.service.DeleteOwnUserResponse)
  })
_sym_db.RegisterMessage(DeleteOwnUserResponse)



_TENSORBOARDWRITERSERVICE = _descriptor.ServiceDescriptor(
  name='TensorBoardWriterService',
  full_name='tensorboard.service.TensorBoardWriterService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=2292,
  serialized_end=3410,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateExperiment',
    full_name='tensorboard.service.TensorBoardWriterService.CreateExperiment',
    index=0,
    containing_service=None,
    input_type=_CREATEEXPERIMENTREQUEST,
    output_type=_CREATEEXPERIMENTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateExperiment',
    full_name='tensorboard.service.TensorBoardWriterService.UpdateExperiment',
    index=1,
    containing_service=None,
    input_type=_UPDATEEXPERIMENTREQUEST,
    output_type=_UPDATEEXPERIMENTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteExperiment',
    full_name='tensorboard.service.TensorBoardWriterService.DeleteExperiment',
    index=2,
    containing_service=None,
    input_type=_DELETEEXPERIMENTREQUEST,
    output_type=_DELETEEXPERIMENTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='PurgeData',
    full_name='tensorboard.service.TensorBoardWriterService.PurgeData',
    index=3,
    containing_service=None,
    input_type=_PURGEDATAREQUEST,
    output_type=_PURGEDATARESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='WriteScalar',
    full_name='tensorboard.service.TensorBoardWriterService.WriteScalar',
    index=4,
    containing_service=None,
    input_type=_WRITESCALARREQUEST,
    output_type=_WRITESCALARRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='WriteTensor',
    full_name='tensorboard.service.TensorBoardWriterService.WriteTensor',
    index=5,
    containing_service=None,
    input_type=_WRITETENSORREQUEST,
    output_type=_WRITETENSORRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetOrCreateBlobSequence',
    full_name='tensorboard.service.TensorBoardWriterService.GetOrCreateBlobSequence',
    index=6,
    containing_service=None,
    input_type=_GETORCREATEBLOBSEQUENCEREQUEST,
    output_type=_GETORCREATEBLOBSEQUENCERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetBlobMetadata',
    full_name='tensorboard.service.TensorBoardWriterService.GetBlobMetadata',
    index=7,
    containing_service=None,
    input_type=_GETBLOBMETADATAREQUEST,
    output_type=_GETBLOBMETADATARESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='WriteBlob',
    full_name='tensorboard.service.TensorBoardWriterService.WriteBlob',
    index=8,
    containing_service=None,
    input_type=_WRITEBLOBREQUEST,
    output_type=_WRITEBLOBRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteOwnUser',
    full_name='tensorboard.service.TensorBoardWriterService.DeleteOwnUser',
    index=9,
    containing_service=None,
    input_type=_DELETEOWNUSERREQUEST,
    output_type=_DELETEOWNUSERRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_TENSORBOARDWRITERSERVICE)

DESCRIPTOR.services_by_name['TensorBoardWriterService'] = _TENSORBOARDWRITERSERVICE

# @@protoc_insertion_point(module_scope)
